==> youtrack_rest_client-0.1.1-py3-none-any.whl: youtrack_rest_client/api/default/delete_admin_projects_id_custom_fields_project_custom_field_id.py <==
from typing import Any, Dict

import httpx

from ...client import Client
from ...types import Response


def _get_kwargs(
    id: str,
    project_custom_field_id: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/admin/projects/{id}/customFields/{projectCustomFieldId}".format(
        client.youtrack_base_url, id=id, projectCustomFieldId=project_custom_field_id
    )

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    id: str,
    project_custom_field_id: str,
    *,
    client: Client,
) -> Response[Any]:
    kwargs = _get_kwargs(
        id=id,
        project_custom_field_id=project_custom_field_id,
        client=client,
    )

    response = httpx.delete(
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    id: str,
    project_custom_field_id: str,
    *,
    client: Client,
) -> Response[Any]:
    kwargs = _get_kwargs(
        id=id,
        project_custom_field_id=project_custom_field_id,
        client=client,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.delete(**kwargs)

    return _build_response(response=response)

==> youtrack_rest_client-0.1.2-py3-none-any.whl: youtrack_rest_client/api/default/delete_admin_projects_id_custom_fields_project_custom_field_id.py <==
from typing import Any, Dict

import httpx

from ...client import Client
from ...types import Response


def _get_kwargs(
    id: "str",
    project_custom_field_id: "str",
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/admin/projects/{id}/customFields/{projectCustomFieldId}".format(
        client.youtrack_base_url, id=id, projectCustomFieldId=project_custom_field_id
    )

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    id: "str",
    project_custom_field_id: "str",
    *,
    client: Client,
) -> Response[Any]:
    kwargs = _get_kwargs(
        id=id,
        project_custom_field_id=project_custom_field_id,
        client=client,
    )

    response = httpx.delete(
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    id: "str",
    project_custom_field_id: "str",
    *,
    client: Client,
) -> Response[Any]:
    kwargs = _get_kwargs(
        id=id,
        project_custom_field_id=project_custom_field_id,
        client=client,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.delete(**kwargs)

    return _build_response(response=response)
